@@ -10,7 +10,7 @@ class JSONSerializer(AbstractSerializer):
     """
 
     def __init__(self):
-        super(JSONSerializer, self).__init__(
+        super().__init__(
             extensions=[
                 "json",
             ],
